summaryrefslogtreecommitdiff
path: root/drivers/staging/tidspbridge/include/dspbridge/io.h
diff options
context:
space:
mode:
authorRene Sapiens <rene.sapiens@ti.com>2010-07-10 02:24:02 (GMT)
committerGreg Kroah-Hartman <gregkh@suse.de>2010-07-22 17:45:35 (GMT)
commitfb6aabb7f8b64aef7c4376b6cd4b760a62f75c5b (patch)
treee887979c80033a4656704455b9c7279448e7cdad /drivers/staging/tidspbridge/include/dspbridge/io.h
parentdaa89e6cdf1ad0ba18680f41237b659ef0c27c72 (diff)
downloadlinux-fsl-qoriq-fb6aabb7f8b64aef7c4376b6cd4b760a62f75c5b.tar.xz
staging: ti dspbridge: Rename words with camel case
The intention of this patch is to rename the remaining variables with camel case. Variables will be renamed avoiding camel case and Hungarian notation. The words to be renamed in this patch are: ======================================== pMemStatBuf to mem_stat_buf pMgrAttrs to mgr_attrts pMgrInfo to mgr_info pNodeEnv to node_env pNodeId to node_uuid pNodeInfo to node_info pNumLibs to num_libs pNumPersLibs to num_pers_libs pObjDef to obj_def pObjUuid to obj_uuid poolPhysBase to pool_phys_base poolSize to pool_size pPctxt to pctxt ppDevContext to dev_cntxt ppDrvInterface to drv_intf pPersistentDepLibs to prstnt_dep_libs pPhyAddr to phy_addr ======================================== Signed-off-by: Rene Sapiens <rene.sapiens@ti.com> Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
Diffstat (limited to 'drivers/staging/tidspbridge/include/dspbridge/io.h')
-rw-r--r--drivers/staging/tidspbridge/include/dspbridge/io.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/drivers/staging/tidspbridge/include/dspbridge/io.h b/drivers/staging/tidspbridge/include/dspbridge/io.h
index aa24535..b8670ca 100644
--- a/drivers/staging/tidspbridge/include/dspbridge/io.h
+++ b/drivers/staging/tidspbridge/include/dspbridge/io.h
@@ -33,10 +33,10 @@
* channel_mgr: Location to store a channel manager object on
* output.
* hdev_obj: Handle to a device object.
* pMgrAttrs: IO manager attributes.
* pMgrAttrs->birq: I/O IRQ number.
* pMgrAttrs->irq_shared: TRUE if the IRQ is shareable.
* pMgrAttrs->word_size: DSP Word size in equivalent PC bytes..
* Returns:
* 0: Success;
* -ENOMEM: Insufficient memory for requested resources.
@@ -46,12 +46,12 @@
* Requires:
* io_init(void) called.
* io_man != NULL.
- * pMgrAttrs != NULL.
+ * mgr_attrts != NULL.
* Ensures:
*/
extern int io_create(OUT struct io_mgr **io_man,
struct dev_object *hdev_obj,
- IN CONST struct io_attrs *pMgrAttrs);
+ IN CONST struct io_attrs *mgr_attrts);
/*
* ======== io_destroy ========
@@ -33,10 +33,10 @@
* output.
* hdev_obj: Handle to a device object.
- * pMgrAttrs: IO manager attributes.
- * pMgrAttrs->birq: I/O IRQ number.
- * pMgrAttrs->irq_shared: TRUE if the IRQ is shareable.
- * pMgrAttrs->word_size: DSP Word size in equivalent PC bytes..
+ * mgr_attrts: IO manager attributes.
+ * mgr_attrts->birq: I/O IRQ number.
+ * mgr_attrts->irq_shared: TRUE if the IRQ is shareable.
+ * mgr_attrts->word_size: DSP Word size in equivalent PC bytes..
* Returns:
* 0: Success;